pub enum MoveBlock {
Use(Vec<UniqueBlock>, Vec<BlockHash>, Vec<PositionalLineageHash>, Option<Vec<Vec<u32>>>, Option<UniqueBlock>),
Deref(Vec<UniqueBlock>),
Promote(Uuid, SequenceHash, Option<u64>, Option<BlockHash>, PositionalLineageHash, Option<Vec<u32>>),
}Expand description
Represents different block movement operations in the cache For Use and Promote variants, block hashes are included for KV event publishing
Variants
Use(Vec<UniqueBlock>, Vec<BlockHash>, Vec<PositionalLineageHash>, Option<Vec<Vec<u32>>>, Option<UniqueBlock>)
Deref(Vec<UniqueBlock>)
Promote(Uuid, SequenceHash, Option<u64>, Option<BlockHash>, PositionalLineageHash, Option<Vec<u32>>)