Module utils

Module utils 

Functions

compute_kv_transfer_delay
Compute the KV transfer delay duration for a given number of input tokens.
compute_prefill_handoff_delay_ms
Compute the modeled handoff delay after a prefill worker emits its terminal token.
prefill_handoff_transfer_timing
sleep_precise
Sleep for the specified duration using timerfd on Linux for precision.
sleep_until_precise
Sleep until the specified deadline using timerfd on Linux for precision.