pub enum RequestOutputBuffering {
CancelOnOverflow {
capacity: NonZeroUsize,
},
FullResponse,
}Expand description
Controls how much output one live request may retain before it is consumed.
Variants
CancelOnOverflow
Cancel the request when its output queue reaches capacity.
Fields

capacity: NonZeroUsizeFullResponse
Buffer the request’s full declared response.